==> chaosmesh-model-6.6.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/AWSChaosSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AWSChaosSpecFluentImpl<A extends AWSChaosSpecFluent<A>> extends BaseFluent<A> implements AWSChaosSpecFluent<A>{
  public AWSChaosSpecFluentImpl() {
  }
  public AWSChaosSpecFluentImpl(AWSChaosSpec instance) {
    this.withAction(instance.getAction()); 
    this.withAwsRegion(instance.getAwsRegion()); 
    this.withDeviceName(instance.getDeviceName()); 
    this.withDuration(instance.getDuration()); 
    this.withEc2Instance(instance.getEc2Instance()); 
    this.withEndpoint(instance.getEndpoint()); 
    this.withSecretName(instance.getSecretName()); 
    this.withVolumeID(instance.getVolumeID()); 
  }
  private String action;
  private String awsRegion;
  private String deviceName;
  private String duration;
  private String ec2Instance;
  private String endpoint;
  private String secretName;
  private String volumeID;
  public String getAction() {
    return this.action;
  }
  public A withAction(String action) {
    this.action=action; return (A) this;
  }
  public Boolean hasAction() {
    return this.action != null;
  }
  public String getAwsRegion() {
    return this.awsRegion;
  }
  public A withAwsRegion(String awsRegion) {
    this.awsRegion=awsRegion; return (A) this;
  }
  public Boolean hasAwsRegion() {
    return this.awsRegion != null;
  }
  public String getDeviceName() {
    return this.deviceName;
  }
  public A withDeviceName(String deviceName) {
    this.deviceName=deviceName; return (A) this;
  }
  public Boolean hasDeviceName() {
    return this.deviceName != null;
  }
  public String getDuration() {
    return this.duration;
  }
  public A withDuration(String duration) {
    this.duration=duration; return (A) this;
  }
  public Boolean hasDuration() {
    return this.duration != null;
  }
  public String getEc2Instance() {
    return this.ec2Instance;
  }
  public A withEc2Instance(String ec2Instance) {
    this.ec2Instance=ec2Instance; return (A) this;
  }
  public Boolean hasEc2Instance() {
    return this.ec2Instance != null;
  }
  public String getEndpoint() {
    return this.endpoint;
  }
  public A withEndpoint(String endpoint) {
    this.endpoint=endpoint; return (A) this;
  }
  public Boolean hasEndpoint() {
    return this.endpoint != null;
  }
  public String getSecretName() {
    return this.secretName;
  }
  public A withSecretName(String secretName) {
    this.secretName=secretName; return (A) this;
  }
  public Boolean hasSecretName() {
    return this.secretName != null;
  }
  public String getVolumeID() {
    return this.volumeID;
  }
  public A withVolumeID(String volumeID) {
    this.volumeID=volumeID; return (A) this;
  }
  public Boolean hasVolumeID() {
    return this.volumeID != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AWSChaosSpecFluentImpl that = (AWSChaosSpecFluentImpl) o;
    if (action != null ? !action.equals(that.action) :that.action != null) return false;
    if (awsRegion != null ? !awsRegion.equals(that.awsRegion) :that.awsRegion != null) return false;
    if (deviceName != null ? !deviceName.equals(that.deviceName) :that.deviceName != null) return false;
    if (duration != null ? !duration.equals(that.duration) :that.duration != null) return false;
    if (ec2Instance != null ? !ec2Instance.equals(that.ec2Instance) :that.ec2Instance != null) return false;
    if (endpoint != null ? !endpoint.equals(that.endpoint) :that.endpoint != null) return false;
    if (secretName != null ? !secretName.equals(that.secretName) :that.secretName != null) return false;
    if (volumeID != null ? !volumeID.equals(that.volumeID) :that.volumeID != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(action,  awsRegion,  deviceName,  duration,  ec2Instance,  endpoint,  secretName,  volumeID,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (action != null) { sb.append("action:"); sb.append(action + ","); }
    if (awsRegion != null) { sb.append("awsRegion:"); sb.append(awsRegion + ","); }
    if (deviceName != null) { sb.append("deviceName:"); sb.append(deviceName + ","); }
    if (duration != null) { sb.append("duration:"); sb.append(duration + ","); }
    if (ec2Instance != null) { sb.append("ec2Instance:"); sb.append(ec2Instance + ","); }
    if (endpoint != null) { sb.append("endpoint:"); sb.append(endpoint + ","); }
    if (secretName != null) { sb.append("secretName:"); sb.append(secretName + ","); }
    if (volumeID != null) { sb.append("volumeID:"); sb.append(volumeID); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/AWSChaosSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AWSChaosSpecFluentImpl<A extends AWSChaosSpecFluent<A>> extends BaseFluent<A> implements AWSChaosSpecFluent<A>{
  public AWSChaosSpecFluentImpl() {
  }
  public AWSChaosSpecFluentImpl(AWSChaosSpec instance) {
    if (instance != null) {
      this.withAction(instance.getAction());
      this.withAwsRegion(instance.getAwsRegion());
      this.withDeviceName(instance.getDeviceName());
      this.withDuration(instance.getDuration());
      this.withEc2Instance(instance.getEc2Instance());
      this.withEndpoint(instance.getEndpoint());
      this.withSecretName(instance.getSecretName());
      this.withVolumeID(instance.getVolumeID());
    }
  }
  private String action;
  private String awsRegion;
  private String deviceName;
  private String duration;
  private String ec2Instance;
  private String endpoint;
  private String secretName;
  private String volumeID;
  public String getAction() {
    return this.action;
  }
  public A withAction(String action) {
    this.action=action; return (A) this;
  }
  public Boolean hasAction() {
    return this.action != null;
  }
  public String getAwsRegion() {
    return this.awsRegion;
  }
  public A withAwsRegion(String awsRegion) {
    this.awsRegion=awsRegion; return (A) this;
  }
  public Boolean hasAwsRegion() {
    return this.awsRegion != null;
  }
  public String getDeviceName() {
    return this.deviceName;
  }
  public A withDeviceName(String deviceName) {
    this.deviceName=deviceName; return (A) this;
  }
  public Boolean hasDeviceName() {
    return this.deviceName != null;
  }
  public String getDuration() {
    return this.duration;
  }
  public A withDuration(String duration) {
    this.duration=duration; return (A) this;
  }
  public Boolean hasDuration() {
    return this.duration != null;
  }
  public String getEc2Instance() {
    return this.ec2Instance;
  }
  public A withEc2Instance(String ec2Instance) {
    this.ec2Instance=ec2Instance; return (A) this;
  }
  public Boolean hasEc2Instance() {
    return this.ec2Instance != null;
  }
  public String getEndpoint() {
    return this.endpoint;
  }
  public A withEndpoint(String endpoint) {
    this.endpoint=endpoint; return (A) this;
  }
  public Boolean hasEndpoint() {
    return this.endpoint != null;
  }
  public String getSecretName() {
    return this.secretName;
  }
  public A withSecretName(String secretName) {
    this.secretName=secretName; return (A) this;
  }
  public Boolean hasSecretName() {
    return this.secretName != null;
  }
  public String getVolumeID() {
    return this.volumeID;
  }
  public A withVolumeID(String volumeID) {
    this.volumeID=volumeID; return (A) this;
  }
  public Boolean hasVolumeID() {
    return this.volumeID != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AWSChaosSpecFluentImpl that = (AWSChaosSpecFluentImpl) o;
    if (!java.util.Objects.equals(action, that.action)) return false;

    if (!java.util.Objects.equals(awsRegion, that.awsRegion)) return false;

    if (!java.util.Objects.equals(deviceName, that.deviceName)) return false;

    if (!java.util.Objects.equals(duration, that.duration)) return false;

    if (!java.util.Objects.equals(ec2Instance, that.ec2Instance)) return false;

    if (!java.util.Objects.equals(endpoint, that.endpoint)) return false;

    if (!java.util.Objects.equals(secretName, that.secretName)) return false;

    if (!java.util.Objects.equals(volumeID, that.volumeID)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(action,  awsRegion,  deviceName,  duration,  ec2Instance,  endpoint,  secretName,  volumeID,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (action != null) { sb.append("action:"); sb.append(action + ","); }
    if (awsRegion != null) { sb.append("awsRegion:"); sb.append(awsRegion + ","); }
    if (deviceName != null) { sb.append("deviceName:"); sb.append(deviceName + ","); }
    if (duration != null) { sb.append("duration:"); sb.append(duration + ","); }
    if (ec2Instance != null) { sb.append("ec2Instance:"); sb.append(ec2Instance + ","); }
    if (endpoint != null) { sb.append("endpoint:"); sb.append(endpoint + ","); }
    if (secretName != null) { sb.append("secretName:"); sb.append(secretName + ","); }
    if (volumeID != null) { sb.append("volumeID:"); sb.append(volumeID); }
    sb.append("}");
    return sb.toString();
  }
  
}
